==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/assist/log/Admin.php <==
<?php
session_start();
$page_id = "045";
include "/SpliceCom/WebManager/assist/.access.php";
// v 3.70
//PJC 06-DEC-2016 - Menu layout change
//PJC 03-NOV-2014 - S8000 updates
//PJC 17-April-2014 - added warning output if no Admin.log
//PJC 10July2013
if (!isset($_SESSION['alert'])) {
	header("Location: index.php");
	exit("Access Via Manager Assist / Logging / Index");
}
$script=$_SERVER['SCRIPT_NAME'];
include "/SpliceCom/WebManager/assist/tzone.php"; // include timezone
if (isset($_REQUEST['clear'])&& $_REQUEST['clear']==1) {
	if ($handle = opendir("/SpliceCom/Web/download")) {
  		while (false !== ($file = readdir($handle))) {
    if ($file[0] == '.' || is_dir("/SpliceCom/Web/download/".$file)) {
       continue;
    }
    if (strtolower(substr($file,-5,5))=='.wlog') unlink("/SpliceCom/Web/download/".$file);
  }
  closedir($handle);
}
header("Location: $script");
}

$cmd = "cat /proc/version";
exec($cmd,$a); $a=$a[0];
$model = (preg_match('~\b(suse|centos)\b~i',$a)) ? "SoftPBX" : "CallServer";
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html>
<head>
<title>Logging - Admin Log</title>
<META HTTP-EQUIV="Pragma" CONTENT="no-cache">
<META HTTP-EQUIV="Cache-Control" CONTENT="no-cache">
<META HTTP-EQUIV="Expires" CONTENT="0">
<META http-equiv="Content-Type" content="text/html; charset=UTF-8">
<link rel="shortcut icon" href="favicon.ico">
<link href="/manager/assist/css/Styles.css" rel="stylesheet" type="text/css">
<script src="/manager/assist/js/wiz/jquery-1.8.0.js" type="text/javascript"></script>
<style type="text/css">
.log { background: #FFF; font-size: 10px; color: #000; border:1px solid #A0A0A0; position:fixed; top:215px; min-width: 200px; min-height: 200px; right:20px; bottom:20px; left:20px; overflow:scroll; margin-top:10px; }
</style>
<script>
 $(document).ready(function() {
	$.ajaxSetup({ cache: false }); refreshId=""; 
	$("#btnStart").click(function () {	$("#log").load("logadmin.php?src=" + $("#search").val()); $("#taildown").hide();
	refreshId = setInterval(function() {
		if ($("#save").attr("checked") == "checked"){
	 	 $("#filename").attr("disabled",true); $("#save").attr("disabled",true); $.ajax({ url : 'logadmin.php?startadmin=1&f=' + $("#filename").val() }); $("#tailimg").show(); $("#taillink").attr('href', '/download/' +$("#filename").val() + '.wlog');
 	}
	$("#log").animate({"scrollTop": $("#log")[0].scrollHeight}, "slow");
 	$("#log").load("logadmin.php?src=" + $("#search").val()); }, 1000);
	});
	$("#btnStop").click(function () { clearInterval(refreshId); $("#log").stop(); $.ajax({ url : 'logadmin.php?stopadmin=1' });	$("#filename").attr("disabled",false); $("#tailimg").hide();
   	if ($("#save").is(':checked')) { $("#taildown").show();  $("#save").prop('checked', false); $("#save").attr("disabled",false); } });
   	$("#btnClear").click(function () { $("#log").empty(); $("#taildown").hide(); });
    $("#font10").click(function() { $("#log").css("font-size","10px"); });
    $("#font12").click(function() { $("#log").css("font-size","12px"); });
    $("#font14").click(function() { $("#log").css("font-size","14px"); });
    $("#font16").click(function() { $("#log").css("font-size","16px"); });
   	$("#clear").click(function(event) { event.preventDefault(); var r=confirm("Clear all \'.wlog\' files from /SpliceCom/Web/download/ ?"); if (r==true)   {  $.ajax({ url : 'logadmin.php?clear=1' }); $("#taildown").hide(); } });
	$(window).bind('beforeunload', function(){ $.ajax({ url : 'logadmin.php?stopadmin=1' }); $("#tailimg").hide(); return 'Any logging initiated by this page has been stopped.'; });
});
</script>
<script language="javascript">
var popupWindow = null;
function centeredPopup(url,winName,w,h,scroll){
LeftPosition = (screen.width) ? (screen.width-w)/2 : 0;
TopPosition = (screen.height) ? (screen.height-h)/2 : 0;
settings =
'height='+h+',width='+w+',top='+TopPosition+',left='+LeftPosition+',scrollbars='+scroll+',resizable'
popupWindow = window.open(url,winName,settings)
}
</script>
</head>
<body>
<div style="position:absolute; top:8px; right:8px" >
<img onClick="window.location = '/manager/assist/log/Admin.php'" src="../images/refresh16.gif" alt="refresh" title="refresh" border="0">&nbsp;&nbsp;
<img onClick="centeredPopup('../help/help_logs.php','help','600','500','yes');return false" src="../images/help16.gif" alt="help" title="help" border="0">&nbsp;&nbsp;
<img onClick="window.location = '../assist.php'" src="../images/assist16.gif" alt="manager assist" title="manager assist" border="0">&nbsp;&nbsp;
<img onClick="window.location = '../index.php'" src="../images/home16.gif" alt="home" title="home" border="0">
</div>

<div style="position:absolute; top:30px; right:8px" >
<a href="index.php" alt="Debug" title="Debug">Debug Settings</a>&nbsp;|&nbsp;<a href="#" alt="Clear" title="Clear" id="clear" class="clear">Clear Old Logs</a><br/><br/>
<strong><?php echo $model ?></strong>: <a href="Admin.php" alt="Admin" title="Admin">Admin</a>&nbsp;|&nbsp;
<?php if ($model=="CallServer") echo "<a href='Gateway.php' alt='Gateway' title='Gateway'>Gateway</a>&nbsp;|&nbsp;"; ?>
<a href="Voicemail.php" alt="Voicemail" title="Voicemail">Voicemail</a>
<?php if ($model=="CallServer") echo "&nbsp;|&nbsp;<a href='Phone.php' alt='Phone' title='Phone'>Phone</a>"; ?>


</div>

<div style="display: none; position:absolute; top:160px; left:342px" id="tailimg"><img src="images/tail.gif"></div>
<div style="display: none; position:absolute; top:120px; right:10%" id="taildown"><a id="taillink" target="_blank" href="#"><img src='../images/down.png' alt='Download Log' title='Download Log' width='50' height='50'><br/>Download</a></div>
<h2><img src='../images/ok.png' style="vertical-align:middle;">&nbsp;Logging - Admin Log</h2>
View the Live Admin Log and optionally save the output to file.<br/>
To save the log output, click Save and then Start Viewer. To stop click Stop Viewer. Navigating away from this page will stop any saving.</br>
A default filename of '<b>DDMMYY_Admin.wlog</b>' is used, this can be changed. All files are saved in /SpliceCom/Web/download/<br/>
<b>Please Note:</b> viewing logs via the web browser uses additional system resources.<br/>

<?php if (file_exists('/SpliceCom/logs/Admin.log')) { ?>

Font Size:
<font size="2"><a href="javascript:void(0);" id="font10">A</a></font>
<font size="4"><a href="javascript:void(0);" id="font12">A</a></font>
<font size="5"><a href="javascript:void(0);" id="font14">A</a></font>
<font size="6"><a href="javascript:void(0);" id="font16">A</a></font>
<div>
<button id="btnStart">Start Viewer</button>
<button id="btnStop">Stop Viewer</button>
<button id="btnClear" />Clear Viewer</button>
<b>Save :</b> <input name='save' id='save' type='checkbox' title='save' value='0'/> <b>Filename :</b> <input type='text' name='filename' id='filename' title='filename' size='20' value='<?php echo date("dmyGis")."_Admin"; ?>'>&nbsp;&nbsp;<b>Search :</b> <input type='text' name='search' id='search' title='search' size='15' value=''>
</div>
<div id="log" class="log">
<h2>Admin Log Viewer</h2>
&nbsp;View the Live Admin.log and optionally save the output to file.<br/>
&nbsp;To save the log output, click Save and then Start Viewer. To stop click Stop Viewer. Navigating away from this page will stop any saving.</br>
&nbsp;A default filename of '<b>DDMMYY_Admin.wlog</b>' is used, this can be changed. All files are saved in /SpliceCom/Web/download/<br/>
&nbsp;A link to download the file is shown once Stop Viewer has been clicked.<br/><br/>
&nbsp;<b>Please Note:</b> viewing logs via the web browser uses additional system resources.
</div>

<?php
	} else {
?>

<br/><br/><br/><span style='font-weight: bold;color:red'>*** Warning ***</span><br/>No Admin.log found in /SpliceCom/logs/<br/>
This normally indicates logging hasn't been enabled on the CallServer.<br/>
For details on how to enable logging please see Manager Asssit <a href="../faq.php" target="_blank">F.A.Q</a> and search for logs.<br/><br/>
The CallServer is still outputing log information, but it is not being recorded to the rolling logs.<br/>
You can view the Admin output using the following command:<br/><br/>
<span class='command'>cat /dev/emlog0</span><br/><br/>
To capture this output to a new file in /SpliceCom/ftp called newlog.log use this command:<br/><br/>
<span class='command'>cat /dev/emlog0 > /SpliceCom/ftp/newlog.log</span><br/><br/>
Press CTRL+C to cancel the capture.<br/><br/>

<?php } ?>

</body>
</html>

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/assist/log/Admin.php <==
<?php
// v 3.80
//PJC 06-DEC-2016 - Menu layout change
//PJC 03-NOV-2014 - S8000 updates
//PJC 17-April-2014 - added warning output if no Admin.log
//PJC 10July2013

session_start();
$page_id = "044";
include "/SpliceCom/WebManager/assist/.access.php";

if (!isset($_SESSION['alert'])) {
	header("Location: index.php");
	exit("Access Via Manager Assist / Logging / Index");
}
$script=$_SERVER['SCRIPT_NAME'];
include "/SpliceCom/WebManager/assist/tzone.php"; // include timezone
if (isset($_REQUEST['clear'])&& $_REQUEST['clear']==1) {
	if ($handle = opendir("/SpliceCom/Web/download")) {
  		while (false !== ($file = readdir($handle))) {
    if ($file[0] == '.' || is_dir("/SpliceCom/Web/download/".$file)) {
       continue;
    }
    if (strtolower(substr($file,-5,5))=='.wlog') unlink("/SpliceCom/Web/download/".$file);
  }
  closedir($handle);
}
header("Location: $script");
}
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html>
<head>
<title>Logging - Admin Log</title>
<META HTTP-EQUIV="Pragma" CONTENT="no-cache">
<META HTTP-EQUIV="Cache-Control" CONTENT="no-cache">
<META HTTP-EQUIV="Expires" CONTENT="0">
<META http-equiv="Content-Type" content="text/html; charset=UTF-8">
<link rel="shortcut icon" href="favicon.ico">
<link href="/manager/assist/css/Styles.css" rel="stylesheet" type="text/css">
<script src="/manager/assist/js/wiz/jquery-1.8.0.js" type="text/javascript"></script>
<style type="text/css">
.log { background: #FFF; font-size: 10px; color: #000; border:1px solid #A0A0A0; position:fixed; top:215px; min-width: 200px; min-height: 200px; right:20px; bottom:20px; left:20px; overflow:scroll; margin-top:10px; }
</style>
<script>
 $(document).ready(function() {
	$.ajaxSetup({ cache: false }); refreshId=""; 
	$("#btnStart").click(function () {	$("#log").load("logadmin.php?src=" + $("#search").val()); $("#taildown").hide();
	refreshId = setInterval(function() {
		if ($("#save").attr("checked") == "checked"){
	 	 $("#filename").attr("disabled",true); $("#save").attr("disabled",true); $.ajax({ url : 'logadmin.php?startadmin=1&f=' + $("#filename").val() }); $("#tailimg").show(); $("#taillink").attr('href', '/download/' +$("#filename").val() + '.wlog');
 	}
	$("#log").animate({"scrollTop": $("#log")[0].scrollHeight}, "slow");
 	$("#log").load("logadmin.php?src=" + $("#search").val()); }, 1000);
	});
	$("#btnStop").click(function () { clearInterval(refreshId); $("#log").stop(); $.ajax({ url : 'logadmin.php?stopadmin=1' });	$("#filename").attr("disabled",false); $("#tailimg").hide();
   	if ($("#save").is(':checked')) { $("#taildown").show();  $("#save").prop('checked', false); $("#save").attr("disabled",false); } });
   	$("#btnClear").click(function () { $("#log").empty(); $("#taildown").hide(); });
    $("#font10").click(function() { $("#log").css("font-size","10px"); });
    $("#font12").click(function() { $("#log").css("font-size","12px"); });
    $("#font14").click(function() { $("#log").css("font-size","14px"); });
    $("#font16").click(function() { $("#log").css("font-size","16px"); });
   	$("#clear").click(function(event) { event.preventDefault(); var r=confirm("Clear all \'.wlog\' files from /SpliceCom/Web/download/ ?"); if (r==true)   {  $.ajax({ url : 'logadmin.php?clear=1' }); $("#taildown").hide(); } });
	$(window).bind('beforeunload', function(){ $.ajax({ url : 'logadmin.php?stopadmin=1' }); $("#tailimg").hide(); return 'Any logging initiated by this page has been stopped.'; });
});
</script>
<script language="javascript">
var popupWindow = null;
function centeredPopup(url,winName,w,h,scroll){
LeftPosition = (screen.width) ? (screen.width-w)/2 : 0;
TopPosition = (screen.height) ? (screen.height-h)/2 : 0;
settings =
'height='+h+',width='+w+',top='+TopPosition+',left='+LeftPosition+',scrollbars='+scroll+',resizable'
popupWindow = window.open(url,winName,settings)
}
</script>
</head>
<body>
<div style="position:absolute; top:8px; right:8px" >
<img onClick="window.location = '/manager/assist/log/Admin.php'" src="../images/refresh16.gif" alt="refresh" title="refresh" border="0">&nbsp;&nbsp;
<img onClick="centeredPopup('../help/help_logs.php','help','600','500','yes');return false" src="../images/help16.gif" alt="help" title="help" border="0">&nbsp;&nbsp;
<img onClick="window.location = '../assist.php'" src="../images/assist16.gif" alt="manager assist" title="manager assist" border="0">&nbsp;&nbsp;
<img onClick="window.location = '../index.php'" src="../images/home16.gif" alt="home" title="home" border="0">
</div>

<div style="position:absolute; top:30px; right:8px" >
<a href="index.php" alt="Debug" title="Debug">Debug Settings</a>&nbsp;|&nbsp;<a href="#" alt="Clear" title="Clear" id="clear" class="clear">Clear Old Logs</a><br/><br/>
<strong>SoftPBX</strong>: <a href="Admin.php" alt="Admin" title="Admin">Admin</a>&nbsp;|&nbsp;
<a href="Voicemail.php" alt="Voicemail" title="Voicemail">Voicemail</a>
</div>

<div style="display: none; position:absolute; top:160px; left:342px" id="tailimg"><img src="images/tail.gif"></div>
<div style="display: none; position:absolute; top:120px; right:10%" id="taildown"><a id="taillink" target="_blank" href="#"><img src='../images/down.png' alt='Download Log' title='Download Log' width='50' height='50'><br/>Download</a></div>
<h2><img src='../images/ok.png' style="vertical-align:middle;">&nbsp;Logging - Admin Log</h2>
View the Live Admin Log and optionally save the output to file.<br/>
To save the log output, click Save and then Start Viewer. To stop click Stop Viewer. Navigating away from this page will stop any saving.</br>
A default filename of '<b>DDMMYY_Admin.wlog</b>' is used, this can be changed. All files are saved in /SpliceCom/Web/download/<br/>
<b>Please Note:</b> viewing logs via the web browser uses additional system resources.<br/>

<?php if (file_exists('/SpliceCom/logs/Admin.log')) { ?>

Font Size:
<font size="2"><a href="javascript:void(0);" id="font10">A</a></font>
<font size="4"><a href="javascript:void(0);" id="font12">A</a></font>
<font size="5"><a href="javascript:void(0);" id="font14">A</a></font>
<font size="6"><a href="javascript:void(0);" id="font16">A</a></font>
<div>
<button id="btnStart">Start Viewer</button>
<button id="btnStop">Stop Viewer</button>
<button id="btnClear" />Clear Viewer</button>
<b>Save :</b> <input name='save' id='save' type='checkbox' title='save' value='0'/> <b>Filename :</b> <input type='text' name='filename' id='filename' title='filename' size='20' value='<?php echo date("dmyGis")."_Admin"; ?>'>&nbsp;&nbsp;<b>Search :</b> <input type='text' name='search' id='search' title='search' size='15' value=''>
</div>
<div id="log" class="log">
<h2>Admin Log Viewer</h2>
&nbsp;View the Live Admin.log and optionally save the output to file.<br/>
&nbsp;To save the log output, click Save and then Start Viewer. To stop click Stop Viewer. Navigating away from this page will stop any saving.</br>
&nbsp;A default filename of '<b>DDMMYY_Admin.wlog</b>' is used, this can be changed. All files are saved in /SpliceCom/Web/download/<br/>
&nbsp;A link to download the file is shown once Stop Viewer has been clicked.<br/><br/>
&nbsp;<b>Please Note:</b> viewing logs via the web browser uses additional system resources.
</div>

<?php
	} else {
?>

<br/><br/><br/><span style='font-weight: bold;color:red'>*** Warning ***</span><br/>No Admin.log found in /SpliceCom/logs/<br/>
This normally indicates logging hasn't been enabled on the CallServer.<br/>
For details on how to enable logging please see Manager Asssit <a href="../faq.php" target="_blank">F.A.Q</a> and search for logs.<br/><br/>
The CallServer is still outputing log information, but it is not being recorded to the rolling logs.<br/>
You can view the Admin output using the following command:<br/><br/>
<span class='command'>cat /dev/emlog0</span><br/><br/>
To capture this output to a new file in /SpliceCom/ftp called newlog.log use this command:<br/><br/>
<span class='command'>cat /dev/emlog0 > /SpliceCom/ftp/newlog.log</span><br/><br/>
Press CTRL+C to cancel the capture.<br/><br/>

<?php } ?>

</body>
</html>
